.. dynsight documentation master file, created by
   sphinx-quickstart on Thu Oct 19 15:55:32 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :hidden:
   :caption: bbprepared
   :maxdepth: 2

   bbprep <bbprep>

.. toctree::
  :hidden:
  :maxdepth: 2
  :caption: Modules:

  Modules <modules>

============
Introduction
============

| GitHub: https://www.github.com/andrewtarzia/bbprepared


:mod:`.bbprepared` is a Python library aimed at simplifying the preparation of
your building blocks for `stk` construction and analysis.




Installation
------------

To get :mod:`.bbprepared`, you can install it with pip::

  $ pip install bbprepared


Examples
--------

There are examples available in the test code in `tests/`.


Acknowledgements
----------------

I developed much of this code when working in the Jelfs group (http://www.jelfs-group.org/)
and formalised that into `bbprepared` while in the Pavan group (https://www.gmpavanlab.com/).

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
